pyxmpp2.sasl.gssapi.GSSAPIClientAuthenticator

pyxmpp2 :: sasl :: gssapi :: GSSAPIClientAuthenticator :: Class GSSAPIClientAuthenticator |
[hide private]

# Class GSSAPIClientAuthenticator

Provides client-side GSSAPI SASL (Kerberos 5) authentication.

Nested Classes | [hide private]
Inherited from `core.ClientAuthenticator`: `__metaclass__`

Instance Methods | [hide private]
__init__(self, password_manager) Initialize a ClientAuthenticator object. |
Response or Failure |
start(self, username, authzid) Start the authentication process. |
Response or Failure |
challenge(self, challenge) Process the server's challenge. |
Success or Failure |
finish(self, data) Handle authentication succes information from the server. |
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `core.ClientAuthenticator`: `__abstractmethods__` Inherited from `core.ClientAuthenticator` (private): `_abc_cache`, `_abc_negative_cache`, `_abc_negative_cache_version`, `_abc_registry`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, password_manager) (Constructor) |
Initialize a ClientAuthenticator object. Parameters: `password_manager` - a password manager providing authentication credentials. Overrides: object.__init__ (inherited documentation)

### start(self, username, authzid) |
Start the authentication process. Parameters: `username` - the username (authentication id). `authzid` - the authorization id requester. Returns: Response or Failure the initial response to send to the server or a failuer indicator. Overrides: core.ClientAuthenticator.start (inherited documentation)

### challenge(self, challenge) |
Process the server's challenge. Parameters: `challenge` - the challenge. Returns: Response or Failure the response or a failure indicator. Overrides: core.ClientAuthenticator.challenge (inherited documentation)

### finish(self, data) |
Handle authentication succes information from the server. Parameters: `data` - the optional additional data returned with the success. Returns: Success or Failure success or failure indicator. Overrides: core.ClientAuthenticator.finish (inherited documentation)